@@ -1,8 +1,10 @@
+import warnings
 from contextlib import suppress
 from importlib.metadata import PackageNotFoundError, version
-import warnings
+from types import ModuleType
+from typing import Optional
 
-_zfpy = None
+_zfpy: Optional[ModuleType] = None
 
 _zfpy_version: tuple = ()
 with suppress(PackageNotFoundError):
@@ -11,22 +13,24 @@ with suppress(PackageNotFoundError):
 if _zfpy_version:
     # Check NumPy version
     _numpy_version: tuple = tuple(map(int, version("numpy").split('.')))
-    if _numpy_version >= (2, 0, 0) and _zfpy_version <= (1, 0, 1):  # pragma: no cover
+    if _numpy_version >= (2, 0, 0) and _zfpy_version < (1, 0, 1):  # pragma: no cover
         _zfpy_version = ()
         warnings.warn(
             "NumPy version >= 2.0.0 detected. The zfpy library is incompatible with this version of NumPy. "
             "Please downgrade to NumPy < 2.0.0 or wait for an update from zfpy.",
             UserWarning,
+            stacklevel=2,
         )
     else:
         with suppress(ImportError):
-            import zfpy as _zfpy
+            import zfpy as _zfpy  # type: ignore[no-redef]
 
 if _zfpy:
-    from .abc import Codec
-    from .compat import ndarray_copy, ensure_contiguous_ndarray, ensure_bytes
     import numpy as np
 
+    from .abc import Codec
+    from .compat import ensure_bytes, ensure_contiguous_ndarray, ndarray_copy
+
     # noinspection PyShadowingBuiltins
     class ZFPY(Codec):
         """Codec providing compression using zfpy via the Python standard
@@ -102,11 +106,8 @@ if _zfpy:
                 return dec
 
         def __repr__(self):
-            r = "%s(mode=%r, tolerance=%s, rate=%s, precision=%s)" % (
-                type(self).__name__,
-                self.mode,
-                self.tolerance,
-                self.rate,
-                self.precision,
+            return (
+                f"{type(self).__name__}(mode={self.mode!r}, "
+                f"tolerance={self.tolerance}, rate={self.rate}, "
+                f"precision={self.precision})"
             )
-            return r
